@@ -28,9 +28,9 @@ public:
 	
 	void show();
 	void resetLines();	
-	void incLines();	
-	void checkLevel();
+	void incLines(int newlines);	
 	void setLevel(int l);
+	void setStartingLevel(int l);
 		
 	int getScore() {return score;}
 	int getLines() {return lines;}
@@ -38,6 +38,8 @@ public:
 	
 	GtkWidget * getWidget()	{return w;}
 	
+	void incScore(int score);
+
 private:
 	GtkWidget *w;
 	GtkWidget *scorew;
